==> openliberty-src-19.0.0.10.zip: open-liberty-gm-19.0.0.10/dev/com.ibm.ws.security.mp.jwt.proxy/src/com/ibm/ws/security/mp/jwt/proxy/MpJwtHelper.java <==
/*******************************************************************************
 * Copyright (c) 2017 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package com.ibm.ws.security.mp.jwt.proxy;

import java.security.Principal;
import java.util.Hashtable;
import java.util.Map;

import javax.security.auth.Subject;

import org.osgi.framework.ServiceReference;
import org.osgi.service.component.ComponentContext;
import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Deactivate;
import org.osgi.service.component.annotations.Modified;
import org.osgi.service.component.annotations.Reference;
import org.osgi.service.component.annotations.ReferenceCardinality;
import org.osgi.service.component.annotations.ReferencePolicy;
import org.osgi.service.component.annotations.ReferencePolicyOption;

import com.ibm.websphere.ras.Tr;
import com.ibm.websphere.ras.TraceComponent;
import com.ibm.ws.kernel.service.util.JavaInfo;
import com.ibm.wsspi.kernel.service.utils.AtomicServiceReference;

/*
 * This is a utility service for MicroProfile JsonWebToken in a subject
 */
@Component(service = MpJwtHelper.class, name = "MpJwtHelper", immediate = true, property = "service.vendor=IBM")
public class MpJwtHelper {
	private static final TraceComponent tc = Tr.register(MpJwtHelper.class);
	static final String JSON_WEB_TOKEN_UTIL_REF = "JsonWebTokenUtil";
	protected final static AtomicServiceReference<JsonWebTokenUtil> JsonWebTokenUtilRef = new AtomicServiceReference<JsonWebTokenUtil>(
			JSON_WEB_TOKEN_UTIL_REF);

	static private boolean isJdk18Up = (JavaInfo.majorVersion() >= 8);

	public MpJwtHelper() {
	}

	// ctor for the unit tests.
	public MpJwtHelper(boolean isJdk18Up) {
		this.isJdk18Up = isJdk18Up;
	}

	public static Principal getJsonWebTokenPricipal(Subject subject) {
		JsonWebTokenUtil jsonWebTokenUtil = getJsonWebTokenUtil();
		if (jsonWebTokenUtil == null) {
			return null;
		}
		return jsonWebTokenUtil.getJsonWebTokenPrincipal(subject);
	}

	public static void addJsonWebToken(Subject subject, Hashtable<String, ?> customProperties, String key) {
		JsonWebTokenUtil jsonWebTokenUtil = getJsonWebTokenUtil();
		if (jsonWebTokenUtil != null && customProperties != null) {
			jsonWebTokenUtil.addJsonWebToken(subject, customProperties, key);
		}
	}

	public static Principal cloneJsonWebToken(Subject subject) {
		JsonWebTokenUtil jsonWebTokenUtil = getJsonWebTokenUtil();
		if (jsonWebTokenUtil != null) {
			return jsonWebTokenUtil.cloneJsonWebToken(subject);
		} else
			return null;
	}

	public static Principal getJsonWebToken(String jwt, String type, String username) {
		JsonWebTokenUtil jsonWebTokenUtil = getJsonWebTokenUtil();
		if (jsonWebTokenUtil != null) {
			return jsonWebTokenUtil.getJsonWebToken(jwt, type, username);
		}
		return null;
	}

	public static void addLoggedOutJwtToList(Principal p) {
		JsonWebTokenUtil jsonWebTokenUtil = getJsonWebTokenUtil();
		if (jsonWebTokenUtil != null) {
			jsonWebTokenUtil.addLoggedOutJwtToList(p);
		}
	}

	private static JsonWebTokenUtil getJsonWebTokenUtil() {
		if (isJavaVersionAtLeast18()) {
			return JsonWebTokenUtilRef.getService();
		} else {
			return null;
		}

	}

	/**
	 * answer if the mp-jwt feature behind this proxy is active or not. Since
	 * JsonWebTokens are part of that, if we can get it, feature is active.
	 */
	public static boolean isMpJwtFeatureActive() {
		return isJavaVersionAtLeast18() && (JsonWebTokenUtilRef.getService() != null);
	}

	private static boolean isJavaVersionAtLeast18() {
		return isJdk18Up;
	}

	@Reference(service = JsonWebTokenUtil.class, name = JSON_WEB_TOKEN_UTIL_REF, cardinality = ReferenceCardinality.OPTIONAL, policy = ReferencePolicy.DYNAMIC, policyOption = ReferencePolicyOption.GREEDY)
	protected void setJsonWebTokenUtil(ServiceReference<JsonWebTokenUtil> ref) {
		if (isJavaVersionAtLeast18()) {
			JsonWebTokenUtilRef.setReference(ref);
		}
	}

	protected void unsetJsonWebTokenUtil(ServiceReference<JsonWebTokenUtil> ref) {
		if (isJavaVersionAtLeast18()) {
			JsonWebTokenUtilRef.unsetReference(ref);
		}
	}

	@Activate
	protected void activate(ComponentContext cc) {
		if (isJavaVersionAtLeast18()) {
			JsonWebTokenUtilRef.activate(cc);
		}
		if (tc.isDebugEnabled()) {
			Tr.debug(tc, "MpJwtHelper service is activated");
		}
	}

	@Modified
	protected void modified(Map<String, Object> props) {
	}

	@Deactivate
	protected void deactivate(ComponentContext cc) {
		if (isJavaVersionAtLeast18()) {
			JsonWebTokenUtilRef.deactivate(cc);
		}
		if (tc.isDebugEnabled()) {
			Tr.debug(tc, "MpJwtHelper service is activated");
		}
	}
}

==> openliberty-src-20.0.0.2.zip: open-liberty-gm-20.0.0.2/dev/com.ibm.ws.security.mp.jwt.proxy/src/com/ibm/ws/security/mp/jwt/proxy/MpJwtHelper.java <==
/*******************************************************************************
 * Copyright (c) 2017 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package com.ibm.ws.security.mp.jwt.proxy;

import java.security.Principal;
import java.util.Hashtable;
import java.util.Map;

import javax.security.auth.Subject;

import org.osgi.framework.ServiceReference;
import org.osgi.service.component.ComponentContext;
import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Deactivate;
import org.osgi.service.component.annotations.Modified;
import org.osgi.service.component.annotations.Reference;
import org.osgi.service.component.annotations.ReferenceCardinality;
import org.osgi.service.component.annotations.ReferencePolicy;
import org.osgi.service.component.annotations.ReferencePolicyOption;

import com.ibm.websphere.ras.Tr;
import com.ibm.websphere.ras.TraceComponent;
import com.ibm.ws.kernel.service.util.JavaInfo;
import com.ibm.wsspi.kernel.service.utils.AtomicServiceReference;

/*
 * This is a utility service for MicroProfile JsonWebToken in a subject
 */
@Component(service = MpJwtHelper.class, name = "MpJwtHelper", immediate = true, property = "service.vendor=IBM")
public class MpJwtHelper {
	private static final TraceComponent tc = Tr.register(MpJwtHelper.class);
	static final String JSON_WEB_TOKEN_UTIL_REF = "JsonWebTokenUtil";
	protected final static AtomicServiceReference<JsonWebTokenUtil> JsonWebTokenUtilRef = new AtomicServiceReference<JsonWebTokenUtil>(
			JSON_WEB_TOKEN_UTIL_REF);

	static private boolean isJdk18Up = (JavaInfo.majorVersion() >= 8);

	public MpJwtHelper() {
	}

	// ctor for the unit tests.
	public MpJwtHelper(boolean isJdk18Up) {
		this.isJdk18Up = isJdk18Up;
	}

	public static Principal getJsonWebTokenPricipal(Subject subject) {
	    JsonWebTokenUtil jsonWebTokenUtil = getJsonWebTokenUtil();
	    if (subject != null && jsonWebTokenUtil != null) {
	        return jsonWebTokenUtil.getJsonWebTokenPrincipal(subject);
	    }
		return null;	
	}

	public static void addJsonWebToken(Subject subject, Hashtable<String, ?> customProperties, String key) {
		JsonWebTokenUtil jsonWebTokenUtil = getJsonWebTokenUtil();
		if (jsonWebTokenUtil != null && customProperties != null && subject != null) {
			jsonWebTokenUtil.addJsonWebToken(subject, customProperties, key);
		}
	}

	public static Principal cloneJsonWebToken(Subject subject) {
		JsonWebTokenUtil jsonWebTokenUtil = getJsonWebTokenUtil();
		if (subject != null && jsonWebTokenUtil != null) {
			return jsonWebTokenUtil.cloneJsonWebToken(subject);
		} else
			return null;
	}

	public static Principal getJsonWebToken(String jwt, String type, String username) {
		JsonWebTokenUtil jsonWebTokenUtil = getJsonWebTokenUtil();
		if (jsonWebTokenUtil != null) {
			return jsonWebTokenUtil.getJsonWebToken(jwt, type, username);
		}
		return null;
	}

	public static void addLoggedOutJwtToList(Principal p) {
		JsonWebTokenUtil jsonWebTokenUtil = getJsonWebTokenUtil();
		if (jsonWebTokenUtil != null) {
			jsonWebTokenUtil.addLoggedOutJwtToList(p);
		}
	}

	private static JsonWebTokenUtil getJsonWebTokenUtil() {
		if (isJavaVersionAtLeast18()) {
			return JsonWebTokenUtilRef.getService();
		} else {
			return null;
		}

	}

	/**
	 * answer if the mp-jwt feature behind this proxy is active or not. Since
	 * JsonWebTokens are part of that, if we can get it, feature is active.
	 */
	public static boolean isMpJwtFeatureActive() {
		return isJavaVersionAtLeast18() && (JsonWebTokenUtilRef.getService() != null);
	}

	private static boolean isJavaVersionAtLeast18() {
		return isJdk18Up;
	}

	@Reference(service = JsonWebTokenUtil.class, name = JSON_WEB_TOKEN_UTIL_REF, cardinality = ReferenceCardinality.OPTIONAL, policy = ReferencePolicy.DYNAMIC, policyOption = ReferencePolicyOption.GREEDY)
	protected void setJsonWebTokenUtil(ServiceReference<JsonWebTokenUtil> ref) {
		if (isJavaVersionAtLeast18()) {
			JsonWebTokenUtilRef.setReference(ref);
		}
	}

	protected void unsetJsonWebTokenUtil(ServiceReference<JsonWebTokenUtil> ref) {
		if (isJavaVersionAtLeast18()) {
			JsonWebTokenUtilRef.unsetReference(ref);
		}
	}

	@Activate
	protected void activate(ComponentContext cc) {
		if (isJavaVersionAtLeast18()) {
			JsonWebTokenUtilRef.activate(cc);
		}
		if (tc.isDebugEnabled()) {
			Tr.debug(tc, "MpJwtHelper service is activated");
		}
	}

	@Modified
	protected void modified(Map<String, Object> props) {
	}

	@Deactivate
	protected void deactivate(ComponentContext cc) {
		if (isJavaVersionAtLeast18()) {
			JsonWebTokenUtilRef.deactivate(cc);
		}
		if (tc.isDebugEnabled()) {
			Tr.debug(tc, "MpJwtHelper service is activated");
		}
	}
}
